########################
Django Simple Email Auth
########################

A Django library for authenticating using verified email addresses. Users may
authenticate using any email address they have verified ownership of.

*******
License
*******

This project is licensed under the MIT License.
